==> uniq-1.2.0.25-py3-none-any.whl: uniq/apis/nb/clients/inventory_manager_client/models/SiteManagementInfo.py <==
#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class SiteManagementInfo(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'description': 'str',


            'deviceIds': 'list[str]',


            'name': 'str',


            'location': 'str',


            'properties': 'object',


            'id': 'str'

        }

        self.attributeMap = {

            'description': 'description',

            'deviceIds': 'deviceIds',

            'name': 'name',

            'location': 'location',

            'properties': 'properties',

            'id': 'id'

        }


        #Description of site

        self.description = None # str

        #Unique identifier of devices that are associated with site

        self.deviceIds = None # list[str]

        #Name of site

        self.name = None # str

        #Location of site

        self.location = None # str

        #Properties of site

        self.properties = None # object

        #Unique identifier of site

        self.id = None # str

==> uniq-1.3.2.30-py3-none-any.whl: uniq/apis/nb/clients/inventory_manager_client/models/SiteManagementInfo.py <==
#!/usr/bin/env python
#pylint: skip-file
# This source code is licensed under the Apache license found in the
# LICENSE file in the root directory of this project.


class SiteManagementInfo(object):


    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {
            
            'name': 'str',
            
            
            'location': 'str',
            
            
            'properties': 'dict',
            
            
            'id': 'str',
            
            
            'description': 'str',
            
            
            'deviceIds': 'list[str]'
            
        }

        self.attributeMap = {
            
            'name': 'name',
            
            'location': 'location',
            
            'properties': 'properties',
            
            'id': 'id',
            
            'description': 'description',
            
            'deviceIds': 'deviceIds'
            
        }       

        
        #Name of site
        
        self.name = None # str
        
        #Location of site
        
        self.location = None # str
        
        #Properties of site
        
        self.properties = None # dict
        
        #Unique identifier of site
        
        self.id = None # str
        
        #Description of site
        
        self.description = None # str
        
        #Unique identifier of devices that are associated with site
        
        self.deviceIds = None # list[str]
